"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Union

class ItemExternalConnectionExternalConnectionNameExternalConnectionName1(str, Enum):
    TAXJAR = 'taxjar'
    AVALARA = 'avalara'
    ANROK = 'anrok'

class ItemExternalConnectionExternalConnectionNameExternalConnectionName(str, Enum):
    STRIPE = 'stripe'
    QUICKBOOKS = 'quickbooks'
    BILL_COM = 'bill.com'
    NETSUITE = 'netsuite'



@dataclasses.dataclass
class ItemExternalConnectionExternalConnectionName:
    pass


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class ItemExternalConnection:
    external_connection_name: Union[ItemExternalConnectionExternalConnectionNameExternalConnectionName, ItemExternalConnectionExternalConnectionNameExternalConnectionName1] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_connection_name') }})
    external_entity_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_entity_id') }})
    

