"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class BillingCycleAlignment(str, Enum):
    r"""Reset billing periods to be aligned with the plan change’s effective date or start of the month. Defaults to `unchanged` which keeps subscription's existing billing cycle alignment."""
    UNCHANGED = 'unchanged'
    PLAN_CHANGE_DATE = 'plan_change_date'
    START_OF_MONTH = 'start_of_month'
