"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import accountingprovider as shared_accountingprovider
from dataclasses_json import Undefined, dataclass_json
from orb import utils


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class AccountingSyncConfiguration:
    accounting_providers: list[shared_accountingprovider.AccountingProvider] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('accounting_providers') }})
    excluded: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('excluded') }})
    

