"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Optional

class AccountingProviderProviderType(str, Enum):
    QUICKBOOKS = 'quickbooks'
    NETSUITE = 'netsuite'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class AccountingProvider:
    external_provider_id: Optional[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_provider_id') }})
    provider_type: AccountingProviderProviderType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('provider_type') }})
    

