"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Union



@dataclasses.dataclass
class AmountDiscountCreationParamsAmountDiscount:
    pass

class AmountDiscountCreationParamsDiscountType(str, Enum):
    AMOUNT = 'amount'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class AmountDiscountCreationParams:
    amount_discount: Union[float, str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount_discount') }})
    r"""Only available if discount_type is `amount`."""
    discount_type: AmountDiscountCreationParamsDiscountType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('discount_type') }})
    

