"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Optional



@dataclasses.dataclass
class IdempotencyConflictHeaders:
    pass

class IdempotencyConflictStatus(int, Enum):
    FOUR_HUNDRED_AND_NINE = 409

class IdempotencyConflictType(str, Enum):
    HTTPS_DOCS_WITHORB_COM_REFERENCE_ERROR_RESPONSES_NUMBER_409_RESOURCE_CONFLICT = 'https://docs.withorb.com/reference/error-responses#409-resource-conflict'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class IdempotencyConflict:
    status: IdempotencyConflictStatus = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    type: IdempotencyConflictType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    detail: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('detail') }})
    headers: Optional[IdempotencyConflictHeaders] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('headers') }})
    title: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})
    

