"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Optional

class TrialConfigTrialPeriodUnit(str, Enum):
    DAYS = 'days'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class TrialConfig:
    trial_period: Optional[int] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('trial_period') }})
    trial_period_unit: TrialConfigTrialPeriodUnit = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('trial_period_unit') }})
    

