"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from orb import utils


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class AmendedUsage:
    duplicate: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('duplicate') }})
    r"""An array of strings, corresponding to idempotency_key's marked as duplicates (previously ingested)"""
    ingested: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('ingested') }})
    r"""An array of strings, corresponding to idempotency_key's which were successfully ingested."""
    

