"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from orb import utils



@dataclasses.dataclass
class FourHundredAndNineError(Exception):
    

    def __str__(self) -> str:
        return utils.marshal_json(self)
