"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import addpriceintervalparams as shared_addpriceintervalparams
from ..shared import editpriceintervalparams as shared_editpriceintervalparams
from dataclasses_json import Undefined, dataclass_json
from orb import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class AddEditPriceIntervalParams:
    add: Optional[list[shared_addpriceintervalparams.AddPriceIntervalParams]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('add'), 'exclude': lambda f: f is None }})
    r"""A list of price intervals to add to the subscription."""
    edit: Optional[list[shared_editpriceintervalparams.EditPriceIntervalParams]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('edit'), 'exclude': lambda f: f is None }})
    r"""A list of price intervals to edit on the subscription."""
    

