"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from orb import utils
from typing import Union

class PercentageDiscountCreationParamsDiscountType(str, Enum):
    PERCENTAGE = 'percentage'



@dataclasses.dataclass
class PercentageDiscountCreationParamsPercentageDiscount:
    pass


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class PercentageDiscountCreationParams:
    discount_type: PercentageDiscountCreationParamsDiscountType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('discount_type') }})
    percentage_discount: Union[float, str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('percentage_discount') }})
    r"""Only available if discount_type is `percentage`. This is a number between 0 and 1."""
    

