"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import amendmentledgerentry as shared_amendmentledgerentry
from ..shared import creditblockexpiryledgerentry as shared_creditblockexpiryledgerentry
from ..shared import decrementledgerentry as shared_decrementledgerentry
from ..shared import expirationchangeledgerentry as shared_expirationchangeledgerentry
from ..shared import incrementledgerentry as shared_incrementledgerentry
from ..shared import paginationmetadata as shared_paginationmetadata
from ..shared import voidinitiatedledgerentry as shared_voidinitiatedledgerentry
from ..shared import voidledgerentry as shared_voidledgerentry
from dataclasses_json import Undefined, dataclass_json
from orb import utils
from typing import Union


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class CreditLedgerEntries:
    data: list[Union[shared_incrementledgerentry.IncrementLedgerEntry, shared_decrementledgerentry.DecrementLedgerEntry, shared_expirationchangeledgerentry.ExpirationChangeLedgerEntry, shared_creditblockexpiryledgerentry.CreditBlockExpiryLedgerEntry, shared_voidledgerentry.VoidLedgerEntry, shared_voidinitiatedledgerentry.VoidInitiatedLedgerEntry, shared_amendmentledgerentry.AmendmentLedgerEntry]] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    pagination_metadata: shared_paginationmetadata.PaginationMetadata = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination_metadata') }})
    

